#
# spec file for package mate-power-manager
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 1.26
Name:           mate-power-manager
Version:        1.26.0
Release:        bp154.1.40
Summary:        MATE Desktop UPower policy management
License:        GPL-2.0-only
URL:            https://mate-desktop.org/
Group:          System/GUI/Other
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
# PATCH-FEATURE-OPENSUSE mate-power-manager-upower-0.99.7.patch -- Restore UPower 0.99.7 support.
Patch0:         mate-power-manager-upower-0.99.7.patch
BuildRequires:  fdupes
BuildRequires:  mate-common >= %{_version}
BuildRequires:  pkgconfig
BuildRequires:  polkit-devel
BuildRequires:  update-desktop-files
BuildRequires:  yelp-tools
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnome-keyring-1)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(libcanberra-gtk3)
BuildRequires:  pkgconfig(libmatepanelapplet-4.0) >= %{_version}
BuildRequires:  pkgconfig(libnotify)
BuildRequires:  pkgconfig(libsecret-1)
BuildRequires:  pkgconfig(mate-desktop-2.0) >= %{_version}
BuildRequires:  pkgconfig(upower-glib)
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xext)
BuildRequires:  pkgconfig(xproto)
BuildRequires:  pkgconfig(xrandr) >= 1.3.0
BuildRequires:  pkgconfig(xrender)
Requires:       upower
Recommends:     %{name}-lang
%glib2_gsettings_schema_requires

%description
MATE Power Manager is a MATE session daemon that acts as a policy
agent on top of UPower, which requires fairly new versions of the
kernel and udev. MATE Power Manager listens for system events and
responds with user-configurable actions.

%package doc
Group:          Documentation/HTML
Summary:        Documentation how to Use Atril
BuildArch:      noarch

%description doc
This package contains the documentation for atril

%lang_package

%prep
%autosetup -p1

%build
NOCONFIGURE=1 mate-autogen
%configure \
  --libexecdir=%{_libexecdir}/%{name}
%make_build

%install
%make_install
%find_lang %{name} %{?no_lang_C}
%fdupes %{buildroot}%{_datadir}

%files
%license COPYING
%doc AUTHORS NEWS README
%{_sysconfdir}/xdg/autostart/mate-power-manager.desktop
%{_bindir}/mate-power-manager
%{_bindir}/mate-power-preferences
%{_bindir}/mate-power-statistics
%{_sbindir}/mate-power-backlight-helper
%{_libexecdir}/%{name}/
%{_datadir}/applications/mate-power-preferences.desktop
%{_datadir}/applications/mate-power-statistics.desktop
%{_datadir}/dbus-1/services/*.service
%{_datadir}/glib-2.0/schemas/*.xml
%{_datadir}/icons/hicolor/*/*/*
%{_datadir}/mate-panel/
%{_datadir}/mate-power-manager/
%{_datadir}/polkit-1/
%{_mandir}/man?/*.?%{?ext_man}

%files doc
%doc %{_datadir}/help/*/%{name}

%files lang -f %{name}.lang
%exclude %{_datadir}/help/*

%changelog
* Sun Aug 22 2021 Jan Engelhardt <jengelh@inai.de>
- Make doc package noarch
* Fri Aug 13 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Translations update
  * update copyright to 2021
  * applets: Do not build the path to the menu files
  * build: Use PACKAGE_URL variable
  * update resource for transifex
  * Update copyright to 2021
  * Remove warning -Wunused-but-set-variable
  * update issue template
  * gpm-backlight: Fix the position of the inline keyword
  * mate-power-preferences: add option to enable keyboard dimming
  * Switch default from libgnome-keyring to libsecret
  * gpm-control.c: Add libsecret implementation to gpm_control_hibernate()
  * gpm-control.c: Add libsecret implementation to gpm_control_suspend()
  * Add autotools support for libsecret
  * brightness applet: Prevent sliding from bogging down the UI
  * Install action and status icons to right location
  * Remove trailing spaces/tabs
  * gpm-kbd-backlight: Remove unused functions
  * Remove unused variable from gpm_notebook_scroll_event_cb
- Split doc package
* Mon Apr 26 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.24.3:
  * Translations update
  * mate-power-preferences: add option to enable keyboard dimming
  * brightness applet: Prevent sliding from bogging down the UI
* Sun Aug 16 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.2:
  * gpm-kbd-backlight: Do not change keyboard back-light, when
    disabled.
  * build: Silent build warnings for distcheck.
  * build: Do not override the default value for
    MATE_COMPILE_WARNINGS.
  * Remove unused entry from autostart.
  * Update translations.
* Tue Mar 17 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.1:
  * glib-genmarshal: Replace deprecated tokens NONE and BOOL.
  * Read authors (updated) from mate-power-manager.about.
  * Use gtk_show_about_dialog to show about dialogue.
  * Remove the CPU wakeups feature.
  * Update copyright year in the About dialogue.
  * Generate missing gpm-* PNGs from new SVGs.
  * Add missing gpm-phone SVGs.
  * Add missing gpm-keboard SVGs.
  * Add missing gpm-mouse SVGs.
  * Update translations.
- Rebase mate-power-manager-upower-0.99.7.patch.
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0 (changes since 1.22.1):
  * Use --without-keyring for make distcheck.
  * brightness-applet: Use GdkSeat operations.
  * Set compiler debug flags using MATE_DEBUG_CHECK.
  * Use WARN_CFLAGS which are only set with
  - -enable-compiler-warnings.
  * Drop obsolete version checks for upower.
  * Require upower-0.99.8.
  * Use up_client_get_devices2().
  * Use gresources for gpm-prefs.ui and gpm-statistics.ui.
  * Avoid g_type_class_add_private.
  * Simplify the installation process of the icons.
  * Remove unused UI file.
  * prefs: Fix mnemonic relationships.
  * gpm-upower: Fix some build warnings.
  * Add scroll interface tabs with mouse wheel.
  * Migrate from intltool to gettext.
  * icons: Add higher resolution icons.
  * Aoid redundant redeclarations.
  * Update translations.
- Drop support for old openSUSE versions.
- Remove mate-power-manager-gtk-3.20.patch.
- Add mate-power-manager-upower-0.99.7.patch: Restore UPower 0.99.7
  support.
* Sun May 12 2019 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.22.1:
  * Help: Remove About section.
  * Add conf option to disable warnings for low mouse power.
  * Help: Update copyright.
  * Help: Use XInclude instead of ENTITY for legal.xml.
  * Update translations.
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * gpm-control: Avoid deprecated "g_settings_list_schemas".
  * media-keys: Always round the render coordinates for media
    icons.
  * media-keys: Tweak the OSD's bright bar position.
  * osd-window: Make the window smaller.
  * media-keys: Make icon smaller in OSD.
  * media-keys: Use constant for icon size in OSD.
  * Fix spelling and grammar mistakes.
  * gpm-kbd-backlight: Replace deprecated GdkDeviceManager.
  * gpm-backlight: Replace deprecated GdkDeviceManager.
  * gpm-brightness: Replace deprecated Gdk functions.
  * Use libtool generated during build instead of external one.
- Rebase mate-power-manager-gtk-3.20.patch.
* Sat Dec 22 2018 sor.alexei@meowr.ru
- Update to version 1.20.3:
  * Disable deprecation warnings for distcheck.
  * Use make functions for HELP_LINGUAS.
  * Add m-p-m help to transifex config.
  * gpm-button: Replace deprecated Gdk functions.
  * Update translations.
* Sat Jun 16 2018 sor.alexei@meowr.ru
- Update to version 1.20.2:
  * inhibit: Always scale icon to match panel size.
  * Inhibit Applet: Fix excessive CPU use.
  * Update translations.
* Wed Apr 11 2018 sor.alexei@meowr.ru
- Update to version 1.20.1:
  * Add a missing window icon to the About dialogue.
  * Scale OSD size correctly on HiDPI displays.
  * Grammar fix.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * Require GTK+ 3.22 and GLib 2.50.
  * Avoid deprecated gdk_screen_get_monitor_,
    gdk_screen_get_width/height(), gdk_display_get_screen()
    functions.
  * Don't use deprecated gtk_show_uri().
  * Actually check the $XPROTO_REQUIRED variable's value.
  * An implementation of WidthOfScreen and HeightOfScreen.
  * Avoid deprecated GtkStock.
  * inhibit applet: Fix rendering of the icon.
  * Correct spelling mistakes.
  * Update translations.
- Add mate-power-manager-gtk-3.20.patch: Restore GLib 2.48 and
  GTK+ 3.20 support.
* Wed Nov  1 2017 sor.alexei@meowr.ru
- Update to version 1.18.1:
  * Don't abort on unknown DBus signal name.
  * Refresh tray icon on icon theme change.
  * Statistics UI: Add style class mpm-statistics.
  * Update translations.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
  * Build: Require xproto >= 7.0.15.
  * Build: Require mate-panel >= 1.17.
  * Move to GTK+3 (require GTK+ >= 3.14), drop the GTK+2 code and
  - -with-gtk build option.
  * Replace deprecated upower suspend/hibernate functions with
    ConsoleKit2 equivalents.
  * Use manpages as is instead of generating them from sgml (and
    don't require docbook2man for build anymore).
  * Some more fixes and cleanups.
  * Update translations.
* Sat Feb 18 2017 sor.alexei@meowr.ru
- Update to version 1.16.2:
  * Build: Remove strict options, they just get in the way.
  * GTK+3: Properly hide brightness applet popup on pressing
    Esc/Enter/Space keys (fixes popup becoming wide instead and
    random applet crashes).
  * GTK+3: Fix mouse scroll over brightness applet icon when
    no popup is shown.
* Sun Feb  5 2017 sor.alexei@meowr.ru
- Update to version 1.16.1:
  * Check both the "Backlight" and "BACKLIGHT" xrandr properties
    (fixes inability to adjust screen backlight on some systems).
  * Statistics: Stop runtime warnings spam on desktop systems.
  * GTK+3: Fix runtime warning in inhibit applet.
  * GTK+3: Fix OSD rendering on non-composited desktop.
  * GTK+3: Add OSD style class for non-composited desktop.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Use GtkAboutDialog instead of MateAboutDialog.
  * Stop depending on libmate-desktop.
  * Show the primary device time remaining as the first entry in
    the context menu.
  * Do not issue a console warning when laptop batteries are empty.
  * GTK+3: Port from libunique to GtkApplication.
  * GTK+3: Add css theming for OSD (MsdOsdWindow).
  * GTK+3: Fix an empty space in tray when system has no battery.
  * GTK+3: Fix lots of deprecations.
  * Some more fixes and cleanups.
  * Make distcheck use a currently selected GTK+ version.
  * Update translations.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0:
  * GTK+3: Fix deprecations in brightness applet.
  * Some more fixes and cleanups.
  * Update Translations.
  * Fix Changelog generation.
* Wed Jan 27 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Drop MateConf migration script.
  * Fix a possible crash when an Xorg function call fails.
  * Some code cleanup.
* Wed Jan  6 2016 sor.alexei@meowr.ru
- Add missing pkgconfig(xrandr), pkgconfig(xrender),
  pkgconfig(x11), pkgconfig(xext), pkgconfig(xproto) dependencies.
* Mon Nov 30 2015 sor.alexei@meowr.ru
- Update to 1.12.1:
  * Allow disabling of power button.
  * Multiple backlight fixes.
  * Gtk3: Do not remove slider background in brightness applet
    (fixes background in some themes).
  * Update translations.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0:
  * Require XRandR 1.3.
  * Retrieve strings directly from gschema (requires intltool
    0.50.1).
  * Gtk3: support custom themes.
  * Gtk3: fix brightness applet behaviour.
  * Some fixes and cleanups.
* Fri Oct  9 2015 sor.alexei@meowr.ru
- Update to 1.11:
  * backlight-helper: Add gmux_backlight to backlight_interfaces.
  * Switch to org.gnome.SessionManager.
  * Show vendor/model information.
  * Fixes change keyboard back light for laptops with levels less
    then 10.
* Wed Sep  2 2015 sor.alexei@meowr.ru
- Update to 1.10.2:
  * Fix keyboard backlight adjustment for laptops with non-standard
    levels.
  * Some bugfixes.
* Wed Jul 15 2015 sor.alexei@meowr.ru
- Update to 1.10.1:
  * Multiple help fixes.
  * Some bugfixes.
  * Update translations.
* Mon May  4 2015 sor.alexei@meowr.ru
- Update to 1.10.0 (changes since 1.9.0):
  * Fix memory leaks.
  * Rename D-Bus service file.
  * Add mate-power-manager-bugreport, and
    mate-power-backlight-helper manpages.
  * Fix GTKBuilder script for media keys popup window.
  * Removed the property that made UI load fail.
  * UPower: handle UP_DEVICE_STATE_UNKNOWN, avoid assert.
  * Fix mate-power-statistics GUI while using Gtk3.
  * Drop udisks1 support.
  * Update translations.
- Spec cleanup.
* Mon Dec  8 2014 p.drouand@gmail.com
- Remove obsolete "--disable-scrollkeeper" option
- Add requirement to pkgconfig(mate-desktop-2.0); new dependency
* Mon Dec  8 2014 p.drouand@gmail.com
- Remove mate-power-manager_dbus_interface_keyboard_backlight_controls.patch
  fixed on upstream release
- Remove autoreconf -fiv; not needed anymore
* Sun Oct 26 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + Add support for UPower 0.99
- Fix version requirements
* Fri Oct  3 2014 p.drouand@gmail.com
- Update to version 1.8.1
  + Fixed "levels is 0" warning if no kbd backlight present
  + Added support for upower-0.99 API
  + Added keywords key to .desktop file
  + Removed "battery recall" logic
- Remove upstreamed patches
  + mate-power-manager-avoid-levels_is_0-warning.patch
  + mate-power-manager-port-to-upower-0.99_API.patch
  + mate-power-manager-remove-battery-recall-logic.patch
  + mate-power-manager-fixes-for-upower1-api-changes.patch
  + mate-power-manager-improve-upower1-support.patch
* Thu Apr 24 2014 p.drouand@gmail.com
- Add mate-power-manager-fixes-for-upower1-api-changes.patch
- Add mate-power-manager-improve-upower1-support.patch
* Thu Apr 17 2014 p.drouand@gmail.com
- Rebase upower-0.99 support :
  + Remove mate-power-manager_fix-use-g_signal-notify.patch;
    mate-power-manager_upower-remove-recall.patch;
    mate-power-manager_upower-update-for-libupower-glib-API-changes.patch;
    mate-power-manager_upower-use-g_signal-notify.patch
    mate-power-manager_upower.patch
  + Add mate-power-manager-avoid-levels_is_0-warning.patch;
    mate-power-manager-port-to-upower-0.99_API.patch;
    mate-power-manager-remove-battery-recall-logic.patch
- Explicitely require upower
* Sun Apr 13 2014 p.drouand@gmail.com
- Add mate-power-manager_upower-update-for-libupower-glib-API-changes-fix.patch,
  mate-power-manager_fix-pref-apply.patch and
  mate-power-manager-statistics-fix.patch; more fixes for upower >= 0.99
  compatibility
- Remove hard requirement of pm-utils, udisks and splashy; package works
  without these packages
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Thu Feb 20 2014 p.drouand@gmail.com
- Update to version 1.7.90 (unstable)
  + use yelp-tools instead of mate-doc-utils
  + fix systemd support
  + switch to libgnome-keyring
- Add mate-power-manager_dbus_interface_keyboard_backlight_controls.patch
- Add mate-power-manager_fix-mouse-click-on-brightness-applet.patch
- Add mate-power-manager_fix-use-g_signal-notify.patch
- Add mate-power-manager_upower-remove-recall.patch
- Add mate-power-manager_upower-update-for-libupower-glib-API-changes.patch
- Add mate-power-manager_upower-use-g_signal-notify.patch
- Add mate-power-manager_upower.patch
* Tue Dec 31 2013 p.drouand@gmail.com
- Update to version 1.6.3
  + Add option to enable deprecations and hide warnings under
  - -enable-extra-warn
  + Update changelog generation.
  + Remove distro folder
  + Add NEWS.GNOME to EXTRA_DIST
  + fix typo in gpm_control_suspend, gpm-control.c
    this fix 'suspend on lid close'
    Close brc#1012718 https://bugzilla.redhat.com/show_bug.cgi?id=1012718
  + fix comment in gpm-manager.c
  + fix systemd-login1 support for gpm_manager_blank_screen
  + fix dbus path gpm phone manager
  + Code improvements and deprecation fixes
  + Remove systemd from configure summary
- Remove mate-power-manager_fix-display-to-sleep-when-inactive.patch;
  merged on upstream release
* Tue Sep 10 2013 p.drouand@gmail.com
- Add switch-to-gnome-keyring.patch; mate-keyring will be drop by upstream
  and use gnome-keyring instead
- Add mate-power-manager_fix-display-to-sleep-when-inactive.patch;
  fix systemd-login1 support for gpm_manager_blank_screen
- Use gnome-keyring instead of mate-keyring; add pkgconfig(gnome-keyring-1)
  BuildRequires
* Tue Sep  3 2013 p.drouand@gmail.com
- Remove rpmlintrc file; org.mate.power.backlight-helper is now allow
  by default in OpenSUSE (bnc#831404)
* Thu Jul 25 2013 p.drouand@gmail.com
- Update to version 1.6.2
  + removed systemd-daemon dependency and check at runtime if
    systemd-logind is running
  + improved systemd-logind support
  + dont rely only on consolekit for button pressed event
* Thu May  2 2013 p.drouand@gmail.com
- Update to version 1.6.1
  + use 'make dist' for tarball
  + add support to use systemd logind for suspend and hibernate instead
    of upower
  + dont print an error if optional hardware is missing
    Closes #54 (https://github.com/mate-desktop/mate-power-manager/issues/54)
- Add --with-systemdsleep to configure otpions
* Mon Apr 29 2013 p.drouand@gmail.com
- No version for Recommends: %%{name}-lang
* Thu Apr  4 2013 p.drouand@gmail.com
- Update to version 1.6.0
  + Add Recommends:     %%{name}-lang = %%{version}-%%{release}
  + update translations
* Sat Mar 16 2013 nmo.marques@gmail.com
- Update to version 1.5.2:
  + move from libmatenotify to libnotify
  + apply 'dont eat logs' patch
  + update translations
  + improve systemd detection/fallback
  + mate-keyring support is now optional
  + manuy other fixes
- Remove mate-power-manager-1.5.1-add_systemd_checks.patch, merged
  upstream
- Remove mate-power-manager-1.5.1-show_power_statistics.patch,
  merged upstream
* Wed Dec  5 2012 nmo.marques@gmail.com
- Add 'splashy' to Requires; without splashy available 'hibernate'
  doesn't work properly.
* Thu Nov 29 2012 nmo.marques@gmail.com
- Add %%{name}-1.5.1-add_systemd_checks.patch: systemd inhibit
  support; requires systemd >= 195, only Factory should enable.
* Mon Nov 26 2012 nmo.marques@gmail.com
- Add libsystemd-login and libsystemd-daemon to BR's and enabled
  systemd-inhibit
* Sun Nov 25 2012 nmo.marques@gmail.com
- Add mate-power-manager-1.5.1-show_power_statistics.patch; select
  Power Statistics in Applications/System Tools
* Fri Nov 23 2012 nmo.marques@gmail.com
- Update to version 1.5.1
  + Systemd inhibit support for MPM
  + Adds on screen display support to keyboard backlight controls
  + Fix FSF headers
  + other minor fixes
- Removed 0001-update-gpl-2.0-to-latest-legal-text.patch
* Fri Nov 23 2012 nmo.marques@gmail.com
- Add pm-utils and udisks to Requires; bnc#790787
* Fri Nov  9 2012 nmo.marques@gmail.com
- Add upower to Requires, otherwise we have a crash and no applet
* Thu Nov  8 2012 nmo.marques@gmail.com
- Initial package
- Add mate-power-manager-rpmlintrc - setBadness to allows package
  to build for testing (polkit policies)
- Add 0001-update-gpl-2.0-to-latest-legal-text.patch - upstreamed
  can be removed next update
